@@ -11,9 +11,10 @@ package Kernel::Output::HTML::TicketOverview::Preview;
 
 use strict;
 use warnings;
+use utf8;
 
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language qw(Translatable);
+use Kernel::Language              qw(Translatable);
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -490,13 +491,11 @@ sub _Show {
         Data  => $StandardTemplates{Answer} || {},
     );
 
-    # customer info
-    if ( $Param{Config}->{CustomerInfo} ) {
-        if ( $Article{CustomerUserID} ) {
-            $Article{CustomerName} = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerName(
-                UserLogin => $Article{CustomerUserID},
-            );
-        }
+    # Add CustomerName
+    if ( $Article{CustomerUserID} ) {
+        $Article{CustomerName} = $Kernel::OM->Get('Kernel::System::CustomerUser')->CustomerName(
+            UserLogin => $Article{CustomerUserID},
+        );
     }
 
     # get ACL restrictions
@@ -514,19 +513,7 @@ sub _Show {
             sort keys %Actions;
     }
 
-    my $ACL = $TicketObject->TicketAcl(
-        Data          => \%PossibleActions,
-        Action        => $Self->{Action},
-        TicketID      => $Article{TicketID},
-        ReturnType    => 'Action',
-        ReturnSubType => '-',
-        UserID        => $Self->{UserID},
-    );
-
     my %AclAction = %PossibleActions;
-    if ($ACL) {
-        %AclAction = $TicketObject->TicketAclActionData();
-    }
 
     # get main object
     my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
@@ -535,6 +522,22 @@ sub _Show {
     my @ActionItems;
     if ( ref $ConfigObject->Get('Ticket::Frontend::PreMenuModule') eq 'HASH' ) {
         my %Menus = %{ $ConfigObject->Get('Ticket::Frontend::PreMenuModule') };
+
+        if (%Menus) {
+            my $ACL = $TicketObject->TicketAcl(
+                Data          => \%PossibleActions,
+                Action        => $Self->{Action},
+                TicketID      => $Article{TicketID},
+                ReturnType    => 'Action',
+                ReturnSubType => '-',
+                UserID        => $Self->{UserID},
+            );
+
+            if ($ACL) {
+                %AclAction = $TicketObject->TicketAclActionData();
+            }
+        }
+
         MENU:
         for my $Menu ( sort keys %Menus ) {
 
@@ -621,11 +624,6 @@ sub _Show {
     }
 
     $Param{IsITSMIncidentProblemManagementInstalled} = $Self->{IsITSMIncidentProblemManagementInstalled};
-    my %AdditionalObjectData;
-    if ( $Self->{IsITSMIncidentProblemManagementInstalled} ) {
-        %AdditionalObjectData = %Ticket;
-    }
-
     $LayoutObject->Block(
         Name => 'DocumentContent',
         Data => {
@@ -635,7 +633,6 @@ sub _Show {
             PillClass         => $PillClass,
             AdditionalClasses => $AdditionalClasses,
             Created           => $Ticket{Created},                 # use value from ticket, not article
-            %AdditionalObjectData,
         },
     );
 
@@ -770,77 +767,6 @@ sub _Show {
         }
     }
 
-    # create output
-    $LayoutObject->Block(
-        Name => 'AgentAnswer',
-        Data => {
-            %Param,
-            %Article,
-            %AclAction,
-        },
-    );
-    if (
-        $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose}
-        && ( !defined $AclAction{AgentTicketCompose} || $AclAction{AgentTicketCompose} )
-        )
-    {
-        my $Access = 1;
-        my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketCompose');
-        if ( $Config->{Permission} ) {
-            my $Ok = $TicketObject->Permission(
-                Type     => $Config->{Permission},
-                TicketID => $Param{TicketID},
-                UserID   => $Self->{UserID},
-                LogNo    => 1,
-            );
-            if ( !$Ok ) {
-                $Access = 0;
-            }
-            if ($Access) {
-                $LayoutObject->Block(
-                    Name => 'AgentAnswerCompose',
-                    Data => {
-                        %Param,
-                        %Article,
-                        %AclAction,
-                    },
-                );
-            }
-        }
-    }
-    if (
-        $ConfigObject->Get('Frontend::Module')->{AgentTicketPhoneOutbound}
-        && (
-            !defined $AclAction{AgentTicketPhoneOutbound}
-            || $AclAction{AgentTicketPhoneOutbound}
-        )
-        )
-    {
-        my $Access = 1;
-        my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketPhoneOutbound');
-        if ( $Config->{Permission} ) {
-            my $OK = $TicketObject->Permission(
-                Type     => $Config->{Permission},
-                TicketID => $Param{TicketID},
-                UserID   => $Self->{UserID},
-                LogNo    => 1,
-            );
-            if ( !$OK ) {
-                $Access = 0;
-            }
-        }
-        if ($Access) {
-            $LayoutObject->Block(
-                Name => 'AgentAnswerPhoneOutbound',
-                Data => {
-                    %Param,
-                    %Article,
-                    %AclAction,
-                },
-            );
-        }
-    }
-
     # ticket type
     if ( $ConfigObject->Get('Ticket::Type') ) {
         $LayoutObject->Block(
@@ -872,7 +798,6 @@ sub _Show {
         }
     }
 
-    # CustomerID and CustomerName
     if ( defined $Article{CustomerID} ) {
         $LayoutObject->Block(
             Name => 'CustomerID',
@@ -882,48 +807,41 @@ sub _Show {
             },
         );
 
-        # test access to frontend module
-        my $Access = $LayoutObject->Permission(
-            Action => 'AgentTicketCustomer',
+        my $CICRWAccess = $LayoutObject->Permission(
+            Action => 'AgentCustomerInformationCenter',
             Type   => 'rw',
         );
-        if ($Access) {
-
-            # test access to ticket
-            my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketCustomer');
-            if ( $Config->{Permission} ) {
-                my $OK = $TicketObject->Permission(
-                    Type     => $Config->{Permission},
-                    TicketID => $Param{TicketID},
-                    UserID   => $Self->{UserID},
-                    LogNo    => 1,
-                );
-                if ( !$OK ) {
-                    $Access = 0;
-                }
-            }
-        }
-
-        # define proper tt block based on permissions
-        my $CustomerIDBlock = $Access ? 'CustomerIDRW' : 'CustomerIDRO';
 
         $LayoutObject->Block(
-            Name => $CustomerIDBlock,
+            Name => $CICRWAccess ? 'CustomerIDRW' : 'CustomerIDRO',
+            Data => {
+                %Param,
+                %Article,
+            },
+        );
+    }
+
+    if ( defined $Article{CustomerName} ) {
+        $LayoutObject->Block(
+            Name => 'CustomerName',
             Data => {
                 %Param,
                 %Article,
             },
         );
 
-        if ( defined $Article{CustomerName} ) {
-            $LayoutObject->Block(
-                Name => 'CustomerName',
-                Data => {
-                    %Param,
-                    %Article,
-                },
-            );
-        }
+        my $CUICRWAccess = $LayoutObject->Permission(
+            Action => 'AgentCustomerUserInformationCenter',
+            Type   => 'rw',
+        );
+
+        $LayoutObject->Block(
+            Name => $CUICRWAccess ? 'CustomerNameRW' : 'CustomerNameRO',
+            Data => {
+                %Param,
+                %Article,
+            },
+        );
     }
 
     # show first response time if needed
@@ -1200,7 +1118,6 @@ sub _Show {
             Data => {
                 %Param,
                 %Article,
-                %AclAction,
             },
         );
     }
@@ -1268,14 +1185,7 @@ sub _Show {
         );
 
         # check if compose link should be shown
-        if (
-            $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose}
-            && (
-                !defined $AclAction{AgentTicketCompose}
-                || $AclAction{AgentTicketCompose}
-            )
-            )
-        {
+        if ( $ConfigObject->Get('Frontend::Module')->{AgentTicketCompose} ) {
             my $Access = 1;
             my $Config = $ConfigObject->Get('Ticket::Frontend::AgentTicketCompose');
             if ( $Config->{Permission} ) {
@@ -1328,7 +1238,6 @@ sub _Show {
         Data         => {
             %Param,
             %Article,
-            %AclAction,
         },
     );
     return \$Output;
