@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -10,8 +10,7 @@ package Kernel::System::DBCRUD::Format;
 
 use strict;
 use warnings;
-
-use Kernel::System::VariableCheck qw(:all);
+use utf8;
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -64,12 +63,11 @@ sub new {
         my $Module       = "Kernel::System::DBCRUD::Format::$Backend";
         my $LoadedModule = $MainObject->Require(
             $Module,
-            Silent => 1,
         );
 
         if ( !$LoadedModule ) {
             $LogObject->Log(
-                Priority => 'info',
+                Priority => 'error',
                 Message  => "# ATTENTION: Can't find backend module for '$Backend'\n\n",
             );
             next BACKEND;
@@ -127,7 +125,12 @@ sub GetContent {
     my $Backend = $Self->{BackendsMap}->{ lc( $Param{Format} ) };
     return 0 if !$Backend;
 
-    my $Content = $Self->{Backends}->{$Backend}->GetContent(%Param);
+    my $Module = $Self->{Backends}->{$Backend};
+    return 0 if !$Module;
+
+    return 0 if !$Module->can('GetContent');
+
+    my $Content = $Module->GetContent(%Param);
 
     return $Content;
 }
@@ -166,6 +169,11 @@ sub SetContent {
     my $Backend = $Self->{BackendsMap}->{ lc( $Param{Format} ) };
     return 0 if !$Backend;
 
+    my $Module = $Self->{Backends}->{$Backend};
+    return 0 if !$Module;
+
+    return 0 if !$Module->can('SetContent');
+
     my $Content = $Self->{Backends}->{$Backend}->SetContent(%Param);
 
     return $Content;
