@@ -6,14 +6,15 @@
 # the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
+## nofilter(TidyAll::Plugin::Znuny::Perl::Require)
 
 package Kernel::System::Loader;
 
 use strict;
 use warnings;
 
-use CSS::Minifier qw(); # default minifier, will only be used if CSS::Minifier:XS is not available.
-use JavaScript::Minifier qw(); # default minifier, will only be used if JavaScript::Minifier:XS is not available.
+use CSS::Minifier        qw();    # default minifier, will only be used if CSS::Minifier:XS is not available.
+use JavaScript::Minifier qw();    # default minifier, will only be used if JavaScript::Minifier:XS is not available.
 
 our @ObjectDependencies = (
     'Kernel::Config',
@@ -65,8 +66,8 @@ Uses caching internally.
             $Filename,
             $Filename2,
         ],
-        Checksum             => '...'       # optional, pass a checksum for the minified file
-        Content              => '...'       # optional, pass direct (already minified) content instead of a file list
+        Checksum             => '...',      # optional, pass a checksum for the minified file
+        Content              => '...',      # optional, pass direct (already minified) content instead of a file list
         Type                 => 'CSS',      # CSS | JavaScript
         TargetDirectory      => $TargetDirectory,
         TargetFilenamePrefix => 'CommonCSS',    # optional, prefix for the target filename
@@ -189,6 +190,12 @@ sub MinifyFiles {
                     );
                 }
 
+                # If Loader::Enabled::CSS is enabled and the css files will be minified,
+                # we need to replace '../../' with '../' with a relative path.
+                # This is necessary because the css files are in the css-cache directory,
+                # but the img files are in the img directory.
+                $Content =~ s{../../}{../}g;
+
                 $Content .= "\n";
             }
             elsif ( $Param{Type} eq 'JavaScript' ) {
@@ -289,7 +296,7 @@ sub GetMinifiedFile {
     my $FileContents = $MainObject->FileRead(
         Location => $Location,
 
-        # It would be more correct to use UTF8 mode, but then the JavaScript::Minifier
+        # It would be more correct to use UTF8 mode, but then the ``JavaScript::Minifier``
         #   will cause timeouts due to extreme slowness on some UT servers. Disable for now.
         #   Unicode in the files still works correctly.
         #Mode     => 'utf8',
@@ -371,7 +378,7 @@ returns a minified version of the given JavaScript Code.
 Warning: this function may cause a die() if there are errors in the file,
 protect against that with eval().
 
-This function internally uses the CPAN module JavaScript::Minifier.
+This function internally uses the CPAN module ``JavaScript::Minifier``.
 As of version 1.05 of that module, there is an issue with regular expressions:
 
 This will cause a die:
@@ -418,7 +425,7 @@ sub CacheGenerate {
     my @Result;
 
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-    ## nofilter(TidyAll::Plugin::OTRS::Perl::LayoutObject)
+    ## nofilter(TidyAll::Plugin::Znuny::Perl::LayoutObject)
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
     my %AgentFrontends = %{ $ConfigObject->Get('Frontend::Module') // {} };
@@ -461,10 +468,10 @@ sub CacheGenerate {
 
 deletes all the loader cache files.
 
-Returns a list of deleted files.
-
     my @DeletedFiles = $LoaderObject->CacheDelete();
 
+Returns a list of deleted files.
+
 =cut
 
 sub CacheDelete {
@@ -538,9 +545,11 @@ sub CacheDelete {
 
 =head2 IsJavaScriptMinifierXSAvailable()
 
-    Tries to load JavaScript::Minifier::XS if available which provides faster creation of minified JavaScript.
+Tries to load JavaScript::Minifier::XS if available which provides faster creation of minified JavaScript.
 
-    Returns true value if JavaScript::Minifier::XS is available and loaded.
+    my $IsJavaScriptMinifierXSAvailable = $LoaderObject->IsJavaScriptMinifierXSAvailable();
+
+Returns true value if JavaScript::Minifier::XS is available and loaded.
 
 =cut
 
@@ -562,9 +571,11 @@ sub IsJavaScriptMinifierXSAvailable {
 
 =head2 IsCSSMinifierXSAvailable()
 
-    Tries to load CSS::Minifier::XS if available which provides faster creation of minified CSS.
+Tries to load ``JavaScript::Minifier::XS`` if available which provides faster creation of minified JavaScript.
 
-    Returns true value if CSS::Minifier::XS is available and loaded.
+    my $IsCSSMinifierXSAvailable = $LoaderObject->IsCSSMinifierXSAvailable();
+
+Returns true value if ``CSS::Minifier::XS`` is available and loaded.
 
 =cut
 
